@@ -1,11 +1,12 @@
-from .claims import Claims, claims
+from .claims_builder import ClaimsBuilder, claims
 from .cose import COSE
 from .cose_key import COSEKey
 from .cwt import CWT, decode, encode_and_encrypt, encode_and_mac, encode_and_sign
 from .exceptions import CWTError, DecodeError, EncodeError, VerifyError
 from .key_builder import KeyBuilder, cose_key
+from .recipient import Recipient
 
-__version__ = "0.2.3"
+__version__ = "0.3.0"
 __title__ = "cwt"
 __description__ = "A Python implementation of CWT/COSE"
 __url__ = "https://python-cwt.readthedocs.io"
@@ -22,10 +23,11 @@ __all__ = [
     "decode",
     "CWT",
     "COSE",
-    "Claims",
+    "ClaimsBuilder",
     "COSEKey",
     "KeyBuilder",
     "cose_key",
+    "Recipient",
     "claims",
     "CWTError",
     "EncodeError",
