@@ -8,6 +8,7 @@ from .cbor_processor import CBORProcessor
 from .cose import COSE
 from .cose_key import COSEKey
 from .exceptions import VerifyError
+from .recipient import Recipient
 
 _CWT_DEFAULT_EXPIRES_IN = 3600  # 1 hour
 _CWT_DEFAULT_LEEWAY = 60  # 1 min
@@ -16,12 +17,34 @@ _CWT_DEFAULT_LEEWAY = 60  # 1 min
 class CWT(CBORProcessor):
     """
     A CWT (CBOR Web Token) Implementaion, which is built on top of
-    a COSE (CBOR Object Signing and Encryption) implementation.
+    :class:`COSE <cwt.COSE>`
+
+    ``cwt.cwt`` is a global object of this class initialized with default settings.
     """
 
     CBOR_TAG = 61
 
     def __init__(self, options: Optional[Dict[str, Any]] = None):
+        """
+        Constructor.
+
+        Args:
+            options (Optional[Dict[str, Any]]): Options for the initial
+                configuration of CWT. At this time, ``expires_in`` (default
+                value: ``3600`` ) and ``leaway`` (default value: ``60``) are
+                only supported. See also :func:`expires_in <cwt.CWT.expires_in>`,
+                :func:`leeway <cwt.CWT.leeway>`.
+
+        Examples:
+
+            >>> from cwt import CWT, claims, cose_key
+            >>> ctx = CWT({"expires_in": 3600*24, "leeway": 10})
+            >>> key = cose_key.from_symmetric_key("mysecret")
+            >>> token = ctx.encode_and_mac(
+            ...     claims.from_json({"iss": "coaps://as.example", "sub": "dajiaji", "cti": "123"}),
+            ...     key,
+            ... )
+        """
         self._expires_in = _CWT_DEFAULT_EXPIRES_IN
         self._leeway = _CWT_DEFAULT_LEEWAY
         self._cose = COSE(options)
@@ -52,7 +75,7 @@ class CWT(CBORProcessor):
     @property
     def leeway(self) -> int:
         """
-        The default leeway in seconds for validating `exp` and `nbf`.
+        The default leeway in seconds for validating ``exp`` and ``nbf``.
         """
         return self._leeway
 
@@ -60,7 +83,8 @@ class CWT(CBORProcessor):
         self,
         claims: Union[Dict[int, Any], bytes],
         key: COSEKey,
-        tagged: Optional[bool] = False,
+        tagged: bool = False,
+        recipients: Optional[List[Recipient]] = None,
     ) -> bytes:
         """
         Encode CWT claims and add MAC to it.
@@ -68,6 +92,7 @@ class CWT(CBORProcessor):
         Args:
             claims (Union[Dict[int, Any], bytes]): A CWT claims object or byte string.
             key (COSEKey): A COSE key used to generate a MAC for the claims.
+            recipients (List[Recipient]): A list of recipient information structures.
             tagged (bool): An indicator whether the response is wrapped by CWT tag(61)
                 or not.
         Returns:
@@ -81,7 +106,7 @@ class CWT(CBORProcessor):
         protected: Dict[int, Any] = {1: key.alg}
         unprotected: Dict[int, Any] = {4: key.kid} if key.kid else {}
         res = self._cose.encode_and_mac(
-            protected, unprotected, claims, key, out="cbor2/CBORTag"
+            protected, unprotected, claims, key, recipients, out="cbor2/CBORTag"
         )
         if tagged:
             return self._dumps(CBORTag(CWT.CBOR_TAG, res))
@@ -91,7 +116,7 @@ class CWT(CBORProcessor):
         self,
         claims: Union[Dict[int, Any], bytes],
         key: Union[COSEKey, List[COSEKey]],
-        tagged: Optional[bool] = False,
+        tagged: bool = False,
     ) -> bytes:
         """
         Encode CWT claims and sign it.
@@ -124,15 +149,17 @@ class CWT(CBORProcessor):
         claims: Union[Dict[int, Any], bytes],
         key: COSEKey,
         nonce: bytes,
-        tagged: Optional[bool] = False,
+        tagged: bool = False,
+        recipients: Optional[List[Recipient]] = None,
     ) -> bytes:
         """
         Encode CWT claims and encrypt it.
 
         Args:
             claims (Union[Dict[int, Any], bytes]): CWT claims.
-            key (COSEKey): A COSE key used to sign the claims.
+            key (COSEKey): A COSE key used to encrypt the claims.
             nonce (bytes): A nonce for encryption.
+            recipients (List[Recipient]): A list of recipient information structures.
             tagged (bool): An indicator whether the response is wrapped by CWT tag(61)
                 or not.
         Returns:
@@ -145,10 +172,9 @@ class CWT(CBORProcessor):
         self._set_default_value(claims)
         protected: Dict[int, Any] = {1: key.alg}
         unprotected: Dict[int, Any] = {4: key.kid} if key.kid else {}
-        if nonce:
-            unprotected[5] = nonce
+        unprotected[5] = nonce
         res = self._cose.encode_and_encrypt(
-            protected, unprotected, claims, key, nonce, out="cbor2/CBORTag"
+            protected, unprotected, claims, key, nonce, recipients, out="cbor2/CBORTag"
         )
         if tagged:
             return self._dumps(CBORTag(CWT.CBOR_TAG, res))
@@ -184,13 +210,12 @@ class CWT(CBORProcessor):
         return cwt
 
     def _validate(self, claims: Union[Dict[int, Any], bytes]):
-        """"""
         if isinstance(claims, bytes):
             nested = self._loads(claims)
             if not isinstance(nested, CBORTag):
-                raise ValueError("bytes-formatted claims need CBOR(COSE) Tag.")
+                raise ValueError("A bytes-formatted claims needs CBOR(COSE) Tag.")
             if nested.tag not in [16, 96, 17, 97, 18, 98]:
-                raise ValueError("Unsupported or unknown CBOR tag.")
+                raise ValueError(f"Unsupported or unknown CBOR tag({nested.tag}).")
             return
         if -260 in claims and not isinstance(claims[-260], dict):
             raise ValueError("hcert(-260) should be map.")
@@ -225,7 +250,6 @@ class CWT(CBORProcessor):
         return
 
     def _verify(self, claims: Dict[int, Any]):
-        """"""
         now = timegm(datetime.utcnow().utctimetuple())
 
         if 4 in claims:  # exp
