@@ -1,4 +1,4 @@
-import json
+# import json
 from typing import Any, Dict, Optional, Union
 
 import cbor2
@@ -36,9 +36,11 @@ from .key_types.symmetric import AESCCMKey, HMACKey
 
 
 class KeyBuilder:
-    """"""
+    """
+    A :class:`COSEKey <cwt.COSEKey>` Builder.
+    """
 
-    COSE_KEY_COMMON_PARAMS = {
+    _COSE_KEY_COMMON_PARAMS = {
         "kty": 1,  # tstr / int
         "kid": 2,  # bstr
         "alg": 3,  # tstr / int
@@ -47,7 +49,7 @@ class KeyBuilder:
         # * label => values
     }
 
-    COSE_KEY_OPERATION_VALUES = {
+    _COSE_KEY_OPERATION_VALUES = {
         "sign": 1,
         "verify": 2,
         "encrypt": 3,
@@ -61,33 +63,66 @@ class KeyBuilder:
     }
 
     def __init__(self, options: Optional[Dict[str, Any]] = None):
-        """"""
+        """
+        Constructor.
+
+        At the current implementation, any ``options`` will be ignored.
+        """
         self._options = options
         return
 
     def from_symmetric_key(
-        self, key: Union[bytes, str], alg: str = "HMAC 256/256"
+        self,
+        key: Union[bytes, str],
+        alg: Union[int, str] = "HMAC 256/256",
+        kid: Union[bytes, str] = b"",
     ) -> COSEKey:
-        """"""
+        """
+        Create a COSE key from a symmetric key.
+
+        Args:
+            key (Union[bytes, str]): A key bytes or string.
+            alg (Union[int, str]): An algorithm label(int) or name(str). Supported ``alg`` are listed
+                in `Supported COSE Algorithms <https://python-cwt.readthedocs.io/en/stable/algorithms.html>`_.
+            kid (Union[bytes, str]): A key identifier.
+        Returns:
+            COSEKey: A COSE key object.
+        Raises:
+            ValueError: Invalid arguments.
+        """
         if isinstance(key, str):
             key = key.encode("utf-8")
-        alg_id = COSE_ALGORITHMS_SYMMETRIC.get(alg, None)
-        if not alg_id:
-            raise ValueError("Unsupported or unknown alg: %s" % alg)
+        alg_id = alg if isinstance(alg, int) else COSE_ALGORITHMS_SYMMETRIC.get(alg, 0)
+        if alg_id == 0:
+            raise ValueError(f"Unsupported or unknown alg({alg}).")
 
         cose_key = {
             1: 4,  # kty: 'Symmetric'
             3: alg_id,  # alg: int
             -1: key,  # k:   bstr
         }
+        if isinstance(kid, str):
+            kid = kid.encode("utf-8")
+        if kid:
+            cose_key[2] = kid
         if alg_id in [4, 5, 6, 7]:
             return HMACKey(cose_key)
         if alg_id in [10, 11, 12, 13, 30, 31, 32, 33]:
             return AESCCMKey(cose_key)
-        raise ValueError("Unsupported or unknown alg(3): %d" % alg_id)
+        raise ValueError(f"Unsupported or unknown alg({alg_id}).")
 
     def from_dict(self, cose_key: Dict[int, Any]) -> COSEKey:
-        """"""
+        """
+        Create a COSE key from a CBOR-like dictionary with numeric keys.
+
+        Args:
+            cose_key (Dict[int, Any]): A CBOR-like dictionary with numeric keys
+                of a COSE key.
+        Returns:
+            COSEKey: A COSE key object.
+        Raises:
+            ValueError: Invalid arguments.
+        """
 
         # Validate COSE Key common parameters.
         if 1 not in cose_key:
@@ -102,29 +137,52 @@ class KeyBuilder:
             if 3 not in cose_key or (
                 not isinstance(cose_key[3], int) and not isinstance(cose_key[3], str)
             ):
-                raise ValueError("alg(3) should be int str(tstr).")
+                raise ValueError("alg(3) should be int or str(tstr).")
             if cose_key[3] in [4, 5, 6, 7]:
                 return HMACKey(cose_key)
             if cose_key[3] in [10, 11, 12, 13, 30, 31, 32, 33]:
                 return AESCCMKey(cose_key)
-            raise ValueError(f"Unsupported or unknown alg(3): {cose_key[3]}")
-        raise ValueError(f"Unsupported or unknown kty(1): {cose_key[1]}")
+            raise ValueError(f"Unsupported or unknown alg(3): {cose_key[3]}.")
+        raise ValueError(f"Unsupported or unknown kty(1): {cose_key[1]}.")
 
     def from_bytes(self, key_data: bytes) -> COSEKey:
-        """"""
+        """
+        Create a COSE key from CBOR-formatted key data.
+
+        Args:
+            key_data (bytes): CBOR-formatted key data.
+        Returns:
+            COSEKey: A COSE key object.
+        Raises:
+            ValueError: Invalid arguments.
+            DecodeError: Failed to decode the key data.
+        """
         cose_key = cbor2.loads(key_data)
         return self.from_dict(cose_key)
 
     def from_jwk(self, jwk: Union[str, bytes, Dict[str, Any]]) -> COSEKey:
         """"""
-        cose_key: Dict[int, Any] = {}
-        if not isinstance(jwk, dict):
-            jwk = json.loads(jwk)
-        # TODO: from JWT to COSE key.
-        return self.from_dict(cose_key)
+        raise NotImplementedError
+        # cose_key: Dict[int, Any] = {}
+        # if not isinstance(jwk, dict):
+        #     jwk = json.loads(jwk)
+        # # TODO: from JWT to COSE key.
+        # return self.from_dict(cose_key)
 
-    def from_pem(self, key_data: Union[str, bytes], kid: bytes = b"") -> COSEKey:
-        """"""
+    def from_pem(
+        self, key_data: Union[str, bytes], kid: Union[bytes, str] = b""
+    ) -> COSEKey:
+        """
+        Create a COSE key from PEM-formatted key data.
+
+        Args:
+            key_data (bytes): A PEM-formatted key data.
+        Returns:
+            COSEKey: A COSE key object.
+        Raises:
+            ValueError: Invalid arguments.
+            DecodeError: Failed to decode the key data.
+        """
         if isinstance(key_data, str):
             key_data = key_data.encode("utf-8")
         key_str = key_data.decode("utf-8")
@@ -139,6 +197,10 @@ class KeyBuilder:
             raise ValueError("Failed to decode PEM.")
 
         cose_key: Dict[int, Any] = {}
+        if isinstance(kid, str):
+            kid = kid.encode("utf-8")
+        if kid:
+            cose_key[2] = kid
         if isinstance(k, EllipticCurvePrivateKey) or isinstance(
             k, EllipticCurvePublicKey
         ):
@@ -155,7 +217,7 @@ class KeyBuilder:
             elif k.curve.name == "secp256k1":
                 cose_key[3] = cose_key[-1] = 8
             else:
-                raise ValueError(f"Unsupported or unknown alg: {k.curve.name}")
+                raise ValueError(f"Unsupported or unknown alg: {k.curve.name}.")
             if isinstance(k, EllipticCurvePublicKey):
                 cose_key[-2] = k.public_numbers().x.to_bytes(key_len, byteorder="big")
                 cose_key[-3] = k.public_numbers().y.to_bytes(key_len, byteorder="big")
@@ -221,6 +283,8 @@ class KeyBuilder:
                 cose_key[-4] = k.private_bytes(
                     Encoding.Raw, PrivateFormat.Raw, NoEncryption()
                 )
+        else:
+            raise ValueError("Unsupported or unknown key: {type(k)}.")
         return self.from_dict(cose_key)
 
 
